@@ -7,19 +7,15 @@ import numpy as np
 
 
 class CameraTests(g.unittest.TestCase):
-
     def test_K(self):
         resolution = (320, 240)
         fov = (60, 40)
-        camera = g.trimesh.scene.Camera(
-            resolution=resolution,
-            fov=fov)
+        camera = g.trimesh.scene.Camera(resolution=resolution, fov=fov)
 
         # ground truth matrix
-        K_expected = np.array([[277.128, 0, 160],
-                               [0, 329.697, 120],
-                               [0, 0, 1]],
-                              dtype=np.float64)
+        K_expected = np.array(
+            [[277.128, 0, 160], [0, 329.697, 120], [0, 0, 1]], dtype=np.float64
+        )
 
         assert np.allclose(camera.K, K_expected, rtol=1e-3)
 
@@ -33,15 +29,11 @@ class CameraTests(g.unittest.TestCase):
         resolution = (320, 240)
         focal = None
         fov = (60, 40)
-        camera = g.trimesh.scene.Camera(
-            resolution=resolution,
-            focal=focal,
-            fov=fov)
+        camera = g.trimesh.scene.Camera(resolution=resolution, focal=focal, fov=fov)
         assert np.allclose(camera.fov, fov)
         camera = g.trimesh.scene.Camera(
-            resolution=resolution,
-            focal=camera.focal,
-            fov=None)
+            resolution=resolution, focal=camera.focal, fov=None
+        )
         assert np.allclose(camera.fov, fov)
 
     def test_focal_updates_on_resolution_change(self):
@@ -53,21 +45,16 @@ class CameraTests(g.unittest.TestCase):
         fov = (60, 40)
 
         # start with initial data
-        base_cam = g.trimesh.scene.Camera(
-            resolution=base_res,
-            fov=fov)
+        base_cam = g.trimesh.scene.Camera(resolution=base_res, fov=fov)
         # update both focal length and resolution
         base_focal = base_cam.focal
         base_cam.resolution = updated_res
 
-        assert not g.np.allclose(base_cam.focal,
-                                 base_focal)
+        assert not g.np.allclose(base_cam.focal, base_focal)
 
         # camera created with same arguments should
         # have the same values
-        new_cam = g.trimesh.scene.Camera(
-            resolution=updated_res,
-            fov=fov)
+        new_cam = g.trimesh.scene.Camera(resolution=updated_res, fov=fov)
         assert g.np.allclose(base_cam.focal, new_cam.focal)
 
     def test_fov_updates_on_resolution_change(self):
@@ -77,9 +64,7 @@ class CameraTests(g.unittest.TestCase):
         base_res = (320, 240)
         updated_res = (640, 480)
         focal = (100, 100)
-        base_cam = g.trimesh.scene.Camera(
-            resolution=base_res,
-            focal=focal)
+        base_cam = g.trimesh.scene.Camera(resolution=base_res, focal=focal)
         base_fov = base_cam.fov
         base_cam.resolution = updated_res
         assert base_cam.fov is not base_fov
@@ -94,10 +79,7 @@ class CameraTests(g.unittest.TestCase):
         Test the "look at points" function
         """
         # original points
-        ori = np.array([[-1, -1],
-                        [1, -1],
-                        [1, 1],
-                        [-1, 1]])
+        ori = np.array([[-1, -1], [1, -1], [1, 1], [-1, 1]])
 
         for _i in range(10):
             # set the extents to be random but positive
@@ -111,8 +93,7 @@ class CameraTests(g.unittest.TestCase):
             T = g.trimesh.scene.cameras.look_at(points + offset, fov)
 
             # check using trig
-            check = (points.ptp(axis=0)[:2] / 2.0) / \
-                g.np.tan(np.radians(fov / 2))
+            check = (np.ptp(points, axis=0)[:2] / 2.0) / g.np.tan(np.radians(fov / 2))
             check += points[:, 2].mean()
 
             # Z should be the same as maximum trig option
@@ -136,6 +117,6 @@ class CameraTests(g.unittest.TestCase):
             assert all(rid.max(axis=0) == current - 1)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     g.trimesh.util.attach_to_log()
     g.unittest.main()
